pub struct TransportMessageMetadata {
pub encoding: Option<String>,
pub content_type: Option<String>,
pub correlation_id: Option<String>,
pub headers: HashMap<String, String>,
pub priority: Option<u8>,
pub ttl: Option<u64>,
pub is_heartbeat: Option<bool>,
}Expand description
Metadata associated with a TransportMessage.
Fields
encoding: Option<String>The encoding of the message payload (e.g., “gzip”).
content_type: Option<String>The MIME type of the message payload (e.g., “application/json”).
correlation_id: Option<String>An ID used to correlate requests and responses.
headers: HashMap<String, String>A map of custom headers.
priority: Option<u8>The priority of the message (higher numbers indicate higher priority).
ttl: Option<u64>The time-to-live for the message, in milliseconds.
is_heartbeat: Option<bool>A marker indicating that this is a heartbeat message.
Implementations
Sourceimpl TransportMessageMetadata
impl TransportMessageMetadata
Sourcepub fn with_content_type(
content_type: impl Into<String>,
) -> TransportMessageMetadata
pub fn with_content_type( content_type: impl Into<String>, ) -> TransportMessageMetadata
Creates a new TransportMessageMetadata with a specified content type.
Sourcepub fn with_correlation_id(
correlation_id: impl Into<String>,
) -> TransportMessageMetadata
pub fn with_correlation_id( correlation_id: impl Into<String>, ) -> TransportMessageMetadata
Creates a new TransportMessageMetadata with a specified correlation ID.
Sourcepub fn with_header(
self,
key: impl Into<String>,
value: impl Into<String>,
) -> TransportMessageMetadata
pub fn with_header( self, key: impl Into<String>, value: impl Into<String>, ) -> TransportMessageMetadata
Adds a header to the metadata using a builder pattern.
Sourcepub const fn with_priority(self, priority: u8) -> TransportMessageMetadata
pub const fn with_priority(self, priority: u8) -> TransportMessageMetadata
Sets the priority of the message.
Sourcepub const fn with_ttl(self, ttl: Duration) -> TransportMessageMetadata
pub const fn with_ttl(self, ttl: Duration) -> TransportMessageMetadata
Sets the time-to-live for the message.
Sourcepub const fn heartbeat(self) -> TransportMessageMetadata
pub const fn heartbeat(self) -> TransportMessageMetadata
Marks the message as a heartbeat.